==> util-1.0.19-sources.jar: rx/library/kit/recyclerview/BaseViewHolder.java <==
package rx.library.kit.recyclerview;

import android.util.SparseArray;
import android.view.View;
import android.widget.Button;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.RelativeLayout;
import android.widget.TextView;

import androidx.recyclerview.widget.RecyclerView;

/**
 * recyclerView的viewHolder封装
 */
public class BaseViewHolder extends RecyclerView.ViewHolder {
    private final SparseArray<View> views;
    private BaseViewAdapter.OnChildClickListener onChildClickListener;
    private int position;

    public BaseViewHolder(View itemView, BaseViewAdapter.OnChildClickListener onChildClickListener) {
        super(itemView);
        views = new SparseArray<>();
        this.onChildClickListener = onChildClickListener;
    }

    public BaseViewHolder setVisibility(int viewId, int visibility) {
        getView(viewId).setVisibility(visibility);
        return this;
    }

    public BaseViewHolder setText(int viewId, String content) {
        getTextView(viewId).setText(content);
        return this;
    }

    public BaseViewHolder setTextColor(int viewId, int color) {
        getTextView(viewId).setTextColor(color);
        return this;
    }

    public BaseViewHolder setImage(int viewId, int resource) {
        getImageView(viewId).setImageResource(resource);
        return this;
    }

    public BaseViewHolder setOnClick(int viewId) {
        setOnClick(viewId, viewId);
        return this;
    }

    public BaseViewHolder setOnClick(int viewId, int id) {
        if (onChildClickListener != null) {
            getView(viewId).setOnClickListener(new OnChildViewClickListener(onChildClickListener, getLayoutPosition(), id));
        }
        return this;
    }

    public TextView getTextView(int viewId) {
        return getView(viewId);
    }

    public Button getButton(int viewId) {
        return getView(viewId);
    }

    public ImageView getImageView(int viewId) {
        return getView(viewId);
    }

    public LinearLayout getLinearLayout(int viewId) {
        return getView(viewId);
    }

    public RelativeLayout getRelativeLayout(int viewId) {
        return getView(viewId);
    }

    @SuppressWarnings("unchecked")
    public <T extends View> T getView(int viewId) {
        View view = views.get(viewId);
        if (view == null) {
            view = itemView.findViewById(viewId);
            views.put(viewId, view);
        }
        return (T) view;
    }
}

==> util-1.0.54-sources.jar: rx/library/kit/recyclerview/BaseViewHolder.java <==
package rx.library.kit.recyclerview;

import android.graphics.Bitmap;
import android.graphics.drawable.Drawable;
import android.util.SparseArray;
import android.view.View;
import android.widget.Button;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.RelativeLayout;
import android.widget.TextView;

import androidx.recyclerview.widget.RecyclerView;

/**
 * recyclerView的viewHolder封装
 */
public class BaseViewHolder extends RecyclerView.ViewHolder {
    private final SparseArray<View> views;
    private BaseViewAdapter.OnChildClickListener onChildClickListener;

    public BaseViewHolder(View itemView, BaseViewAdapter.OnChildClickListener onChildClickListener) {
        super(itemView);
        views = new SparseArray<>();
        this.onChildClickListener = onChildClickListener;
    }

    public BaseViewHolder setVisibility(int viewId, int visibility) {
        getView(viewId).setVisibility(visibility);
        return this;
    }

    public BaseViewHolder setText(int viewId, String content) {
        getTextView(viewId).setText(content);
        return this;
    }

    public BaseViewHolder setTextColor(int viewId, int color) {
        getTextView(viewId).setTextColor(color);
        return this;
    }

    public BaseViewHolder setImage(int viewId, int resource) {
        getImageView(viewId).setImageResource(resource);
        return this;
    }

    public BaseViewHolder setImageBitmap(int viewId, Bitmap bitmap) {
        getImageView(viewId).setImageBitmap(bitmap);
        return this;
    }

    public BaseViewHolder setImageDrawable(int viewId, Drawable drawable) {
        getImageView(viewId).setImageDrawable(drawable);
        return this;
    }

    public BaseViewHolder setOnClick(int viewId) {
        setOnClick(viewId, viewId);
        return this;
    }

    public BaseViewHolder setOnClick(int viewId, int id) {
        if (onChildClickListener != null) {
            getView(viewId).setOnClickListener(new OnChildViewClickListener(onChildClickListener, getLayoutPosition(), id));
        }
        return this;
    }

    public TextView getTextView(int viewId) {
        return getView(viewId);
    }

    public Button getButton(int viewId) {
        return getView(viewId);
    }

    public ImageView getImageView(int viewId) {
        return getView(viewId);
    }

    public LinearLayout getLinearLayout(int viewId) {
        return getView(viewId);
    }

    public RelativeLayout getRelativeLayout(int viewId) {
        return getView(viewId);
    }

    @SuppressWarnings("unchecked")
    public <T extends View> T getView(int viewId) {
        View view = views.get(viewId);
        if (view == null) {
            view = itemView.findViewById(viewId);
            views.put(viewId, view);
        }
        return (T) view;
    }
}
